import React, { useState, useMemo, useLayoutEffect } from 'react';
import C from 'calendar-npm';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".container {\r\n    display: flex;\r\n    grid-gap: 0 20px;\r\n    user-select: none;\r\n    flex-wrap: wrap;\r\n    justify-content: center;\r\n    overflow-y: auto;\r\n}\r\n\r\n.container svg {\r\n    pointer-events: none;\r\n}\r\n.container .weekday {\r\n    padding: 6px 16px;\r\n}\r\n\r\n.container .navigation {\r\n    display: flex;\r\n    justify-content: space-around;\r\n    align-items: center;\r\n    margin-bottom: 20px;\r\n    font-size: 18px;\r\n    font-weight: 600;\r\n}\r\n\r\n.container .navigation > button {\r\n    cursor: pointer;\r\n    border: none;\r\n    background-color: transparent;\r\n}\r\n\r\n.container .weeks {\r\n    display: grid;\r\n    grid-template-columns: auto auto auto auto auto auto auto;\r\n    grid-gap: 4px 0;\r\n}\r\n\r\n.container .weeks {\r\n    margin-bottom: 10px;\r\n    color: #94a3b8;\r\n    font-size: 18px;\r\n    font-weight: 700;\r\n}\r\n\r\n.container .weekday {\r\n    text-align: center;\r\n}\r\n\r\n.container .weekday:first-child {\r\n    color: #f87171;\r\n}\r\n.container .days {\r\n    display: grid;\r\n    grid-template-columns: auto auto auto auto auto auto auto;\r\n    grid-gap: 4px 0;\r\n}\r\n.container .day {\r\n    all: unset;\r\n    display: flex;\r\n    justify-content: center;\r\n    align-items: center;\r\n    cursor: pointer;\r\n    outline: none;\r\n    transition: all 260ms ease;\r\n    padding: 6px 16px;\r\n    color: rgba(0, 0, 0, 0.8);\r\n}\r\n.container .selected-day {\r\n    background-color: #10b981;\r\n    color: white;\r\n    border-radius: 10px;\r\n}\r\n\r\n.container .selected-day:hover {\r\n    background-color: #10b98159;\r\n}\r\n\r\n.container .selected-range {\r\n    background-color: #e2e8f0;\r\n}\r\n\r\n.container .selected_day_1 {\r\n    border-radius: 10px 0 0 10px;\r\n    background-color: #10b981;\r\n}\r\n\r\n.container .selected_day_2 {\r\n    border-radius: 0 10px 10px 0;\r\n    background-color: #10b981;\r\n}\r\n\r\n.container .selected_day_1,\r\n.container .selected_day_2 {\r\n    color: white;\r\n}\r\n\r\n.container .current-month:hover {\r\n    background-color: #10b98159;\r\n}\r\n\r\n.container .selected-rang:hover {\r\n    border-radius: 0;\r\n}\r\n.container .prev-month,\r\n.container .next-month {\r\n    color: #cbd5e1;\r\n}\r\n.container .nowDay {\r\n    font-weight: 600;\r\n}\r\n";
styleInject(css_248z);

var Block = function Block(_ref) {
  var _calendar$selectedDat, _calendar$selectedDat2, _calendar$weekDays;

  var onChange = _ref.onChange,
      calendar = _ref.calendar,
      index = _ref.index,
      renderWeekDays = _ref.renderWeekDays,
      renderNavigation = _ref.renderNavigation,
      renderDays = _ref.renderDays,
      calendarCounts = _ref.calendarCounts,
      disablePrevNextDates = _ref.disablePrevNextDates,
      _ref$range = _ref.range,
      range = _ref$range === void 0 ? false : _ref$range;

  var _useState = useState(false),
      rerender = _useState[0],
      setRerender = _useState[1];

  var onChangeCalendar = function onChangeCalendar() {
    onChange && onChange();
    setRerender(!rerender);
  };

  return React.createElement("div", null, renderNavigation ? renderNavigation({
    selectedDate: calendar == null ? void 0 : calendar.selectedDate,
    currentDate: calendar.currentDate,
    months: calendar.months,
    weekDays: calendar.weekDays,
    events: {
      toNextMonth: function toNextMonth() {
        calendar.toNextMonth();
        setRerender(!rerender);
      },
      toPrevMonth: function toPrevMonth() {
        calendar.toPrevMonth();
        setRerender(!rerender);
      },
      toNextYear: function toNextYear() {
        calendar.toNextYear();
        setRerender(!rerender);
      },
      toPrevYear: function toPrevYear() {
        calendar.toPrevYear();
        setRerender(!rerender);
      },
      toDate: function toDate(date) {
        return calendar.toDate(date);
      }
    }
  }) : React.createElement("div", {
    className: 'navigation'
  }, React.createElement("button", {
    onClick: function onClick() {
      calendar == null ? void 0 : calendar.toPrevYear();
      onChangeCalendar();
    }
  }, '<<'), React.createElement("button", {
    onClick: function onClick() {
      calendar == null ? void 0 : calendar.toPrevMonth();
      onChangeCalendar();
    }
  }, '<'), (calendar == null ? void 0 : (_calendar$selectedDat = calendar.selectedDate) == null ? void 0 : _calendar$selectedDat.toString().split(" ")[3]) + "  " + (calendar == null ? void 0 : (_calendar$selectedDat2 = calendar.selectedDate) == null ? void 0 : _calendar$selectedDat2.toString().split(" ")[1]), React.createElement("button", {
    onClick: function onClick() {
      calendar == null ? void 0 : calendar.toNextMonth();
      onChangeCalendar();
    }
  }, '>'), React.createElement("button", {
    onClick: function onClick() {
      calendar == null ? void 0 : calendar.toNextYear();
      onChangeCalendar();
    }
  }, '>>')), renderWeekDays ? renderWeekDays(calendar.weekDays) : React.createElement("div", {
    className: 'weeks'
  }, calendar == null ? void 0 : (_calendar$weekDays = calendar.weekDays) == null ? void 0 : _calendar$weekDays.map(function (day, i) {
    return React.createElement("div", {
      key: i,
      className: ['weekday'].join(" ")
    }, day.substring(0, 1));
  })), React.createElement(Days, {
    calendar: calendar,
    range: range,
    calendarCounts: calendarCounts,
    index: index,
    onChange: onChangeCalendar,
    disablePrevNextDates: disablePrevNextDates,
    renderDays: renderDays
  }));
};

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

var Days = function Days(_ref) {
  var _calendar$days;

  var calendar = _ref.calendar,
      range = _ref.range,
      calendarCounts = _ref.calendarCounts,
      index = _ref.index,
      onChange = _ref.onChange,
      disablePrevNextDates = _ref.disablePrevNextDates,
      renderDays = _ref.renderDays;

  var _onClick = function onClick(day) {
    calendar.toDate(day.date, calendarCounts === 1 ? day.date : undefined);
    onChange && onChange();
  };

  return React.createElement("div", {
    className: 'days'
  }, calendar == null ? void 0 : (_calendar$days = calendar.days) == null ? void 0 : _calendar$days.map(function (day, i) {
    if (renderDays) {
      return renderDays(_extends({}, day, {
        onClick: function onClick() {
          return _onClick(day);
        },
        key: day.date.getTime(),
        defaultStyles: ['day', day.status, range && calendarCounts > 1 ? day.status === 'selected-day' ? "selected_day_" + (index + 1) : '' : '', range ? rangeSelectionLogic(index, day.date, calendar, calendarCounts) : '', range ? rangeSelectedRangeStyles(calendar, day) : ''].join(' ')
      }));
    }

    return React.createElement("button", {
      key: i,
      disabled: disablePrevNextDates && day.status !== 'selected-day' && day.status !== 'current-month',
      "data-index": i,
      className: ['day', day.status, range && calendarCounts > 1 ? day.status === 'selected-day' ? "selected_day_" + (index + 1) : '' : '', range ? rangeSelectionLogic(index, day.date, calendar, calendarCounts) : '', range ? rangeSelectedRangeStyles(calendar, day) : '', calendar.currentDate.setHours(0, 0, 0, 0) === day.date.getTime() ? 'nowDay' : ''].join(' '),
      onClick: function onClick() {
        return _onClick(day);
      }
    }, day.label);
  }));
};

var rangeSelectionLogic = function rangeSelectionLogic(index, dayDate, calendar, calendarCounts) {
  if (calendarCounts > 1) {
    if (index === 0) {
      return dayDate.getTime() > calendar.selectedDate.getTime() ? 'selected-range' : '';
    } else if (index === calendarCounts - 1) {
      return dayDate.getTime() < calendar.selectedDate.getTime() ? 'selected-range' : '';
    }
  }

  if (calendar.hasOwnProperty('range') && calendar.range.length > 0) {
    var _calendar$range$, _calendar$range$2;

    if ((dayDate == null ? void 0 : dayDate.getTime()) >= ((_calendar$range$ = calendar.range[0]) == null ? void 0 : _calendar$range$.getTime()) && (dayDate == null ? void 0 : dayDate.getTime()) <= ((_calendar$range$2 = calendar.range[1]) == null ? void 0 : _calendar$range$2.getTime())) {
      return 'selected-range';
    }
  }

  return '';
};

var rangeSelectedRangeStyles = function rangeSelectedRangeStyles(calendar, day) {
  var _calendar$range$3, _calendar$range$4, _calendar$range$5, _day$date, _calendar$range$6, _calendar$range$7, _calendar$range$8, _day$date2, _calendar$range$9, _calendar$range$10;

  return calendar.hasOwnProperty('range') && ((calendar == null ? void 0 : (_calendar$range$3 = calendar.range[0]) == null ? void 0 : _calendar$range$3.getTime()) !== (calendar == null ? void 0 : (_calendar$range$4 = calendar.range[1]) == null ? void 0 : _calendar$range$4.getTime()) && (calendar == null ? void 0 : (_calendar$range$5 = calendar.range[0]) == null ? void 0 : _calendar$range$5.getTime()) === ((_day$date = day.date) == null ? void 0 : _day$date.getTime()) ? 'selected_day_1' : (calendar == null ? void 0 : (_calendar$range$6 = calendar.range[0]) == null ? void 0 : _calendar$range$6.getTime()) !== (calendar == null ? void 0 : (_calendar$range$7 = calendar.range[1]) == null ? void 0 : _calendar$range$7.getTime()) && (calendar == null ? void 0 : (_calendar$range$8 = calendar.range[1]) == null ? void 0 : _calendar$range$8.getTime()) === ((_day$date2 = day.date) == null ? void 0 : _day$date2.getTime()) ? 'selected_day_2' : (calendar == null ? void 0 : (_calendar$range$9 = calendar.range[0]) == null ? void 0 : _calendar$range$9.getTime()) === (calendar == null ? void 0 : (_calendar$range$10 = calendar.range[1]) == null ? void 0 : _calendar$range$10.getTime()) ? '.selected-day' : '');
};

var Calendar = function Calendar(_ref) {
  var _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? function () {} : _ref$onChange,
      _ref$date = _ref.date,
      date = _ref$date === void 0 ? new Date() : _ref$date,
      _ref$containerClassNa = _ref.containerClassName,
      containerClassName = _ref$containerClassNa === void 0 ? "" : _ref$containerClassNa,
      renderWeekDays = _ref.renderWeekDays,
      renderNavigation = _ref.renderNavigation,
      renderDays = _ref.renderDays,
      _ref$calendarCounts = _ref.calendarCounts,
      calendarCounts = _ref$calendarCounts === void 0 ? 1 : _ref$calendarCounts,
      _ref$range = _ref.range,
      range = _ref$range === void 0 ? false : _ref$range,
      _ref$disablePrevNextD = _ref.disablePrevNextDates,
      disablePrevNextDates = _ref$disablePrevNextD === void 0 ? true : _ref$disablePrevNextD;
  var calendars = useMemo(function () {
    var now = new Date(date);
    return Array.from({
      length: calendarCounts
    }, function (_, k) {
      var _dates = new Date(now.getFullYear(), now.getMonth() + k, now.getDate());

      return new C(_dates);
    });
  }, [calendarCounts, date]);
  useLayoutEffect(function () {
    onChange(calendars.map(function (e) {
      return e.selectedDate;
    }));
  }, []);

  var onChangeCalendar = function onChangeCalendar() {
    onChange(calendars.map(function (e) {
      return e.selectedDate;
    }));
  };

  return React.createElement("div", {
    className: ['container', containerClassName].join(" "),
    style: {
      gridTemplateColumns: "repeat(" + calendarCounts + ", auto)"
    }
  }, calendars == null ? void 0 : calendars.map(function (calendar, index) {
    return React.createElement(Block, {
      key: index,
      index: index,
      onChange: onChangeCalendar,
      calendars: calendars,
      calendar: calendar,
      renderWeekDays: renderWeekDays,
      renderNavigation: renderNavigation,
      renderDays: renderDays,
      calendarCounts: calendarCounts,
      range: range,
      disablePrevNextDates: disablePrevNextDates
    });
  }));
};

export default Calendar;
//# sourceMappingURL=react-calendar-npm.esm.js.map
